<!DOCTYPE html>
<html lang="en">
<head>
	<title>{{title}}</title>
	<meta content="text/html;charset=utf-8" http-equiv="Content-Type">
	<meta name="viewport" content="width=device-width, initial-scale=1.0">
	<link rel="icon" href="{{icon}}">
	<style>
{{css}}
	</style>
	<style>
{{custom_css}}
	</style>
</head>
<body>
<div id="content">
</div>
<script>
window.CUCUMBER_MESSAGES = [{{messages}}];
</script>
<script>
{{script}}
</script>
<script>
{{custom_script}}
</script>
</body>
</html>
